bodhi\.client\.bindings
=======================

.. automodule:: bodhi.client.bindings

   
   
   .. rubric:: Functions

   .. autosummary::
   
      errorhandled
      input
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BodhiClient
      ConfigParser
      OpenIdBaseClient
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      AuthError
      BodhiClientException
      FedoraClientError
      UpdateNotFound
   
   